@@ -66,6 +66,13 @@ SHORT_NAMES = {'quit': 'Quit',
                'comp-prev': 'Previous completion option',
                'comp-use': 'Use selected completion option',
                'comp-close': 'Close the completion list',
+               'prio-a': 'Set priority to (A)',
+               'prio-b': 'Set priority to (B)',
+               'prio-c': 'Set priority to (C)',
+               'prio-d': 'Set priority to (D)',
+               'prio-none': 'Remove priority',
+               'prio-up': 'Increase priority',
+               'prio-down': 'Decrease priority',
                }
 
 
@@ -1046,7 +1053,9 @@ class HelpScreen(RemappedScrollPanel):
         nav_fncs = ['next-item', 'prev-item', 'page-up', 'page-down',
                     'first-item', 'last-item', 'jump-to']
         edt_fncs = ['toggle-hidden', 'toggle-done', 'edit-task', 'create-task',
-                    'toggle-tracking', 'delegate', 'save-template', 'load-template', 'delete-task']
+                    'toggle-tracking', 'delegate', 'save-template', 'load-template',
+                    'delete-task', 'prio-a', 'prio-b', 'prio-c', 'prio-c',
+                    'prio-none', 'prio-up', 'prio-down']
         search_fncs = ['search', 'load-search', 'save-search', 'search-context', 'search-project']
         meta_fncs = ['show-help', 'open-manual', 'quit', 'cancel', 'refresh-screen',
                      'reload-tasks']
@@ -1153,7 +1162,7 @@ class JumpToIndexReader(RemappedInputLine):
 
 
 class CursesApplication(Application):
-    def __init__(self, sources, conf):
+    def __init__(self, sources, conf, initial_search):
         super().__init__()
         self.quit = False
         self.sources = sources
@@ -1161,6 +1170,7 @@ class CursesApplication(Application):
         self.colors = {}
         self.color_cache = {}
         self.all_tasks = []
+        self.initial_search = initial_search
 
         # sorting and searching
         self.sort_order = utils.build_sort_order(common.DEFAULT_SORT_ORDER)
@@ -1299,6 +1309,13 @@ class CursesApplication(Application):
             's': 'save-search',
             '?': 'show-help',
             'm': 'open-manual',
+            'A': 'prio-a',
+            'B': 'prio-b',
+            'C': 'prio-c',
+            'D': 'prio-d',
+            '+': 'prio-up',
+            '-': 'prio-down',
+            '=': 'prio-none',
             }
         self.editor_key_mapping = {
             '^C': 'cancel',
@@ -1347,6 +1364,13 @@ class CursesApplication(Application):
             'delegate': self.do_delegate,
             'open-manual': utils.open_manual,
             'delete-task': self.do_delete,
+            'prio-up': self.do_prio_up,
+            'prio-down': self.do_prio_down,
+            'prio-none': lambda: self.do_set_prio(None),
+            'prio-a': lambda: self.do_set_prio('A'),
+            'prio-b': lambda: self.do_set_prio('B'),
+            'prio-c': lambda: self.do_set_prio('C'),
+            'prio-d': lambda: self.do_set_prio('D'),
             }
 
         self.search_bar = None
@@ -1374,6 +1398,13 @@ class CursesApplication(Application):
 
         self.resize()
         self.update_tasks()
+        if self.initial_search is not None:
+            searches = utils.parse_searches()
+            if self.initial_search in searches:
+                self.set_named_search(searches, self.initial_search)
+                self.paint(True)
+            else:
+                self.set_search(self.initial_search)
         self.paint()
         curses.doupdate()
 
@@ -1414,6 +1445,7 @@ class CursesApplication(Application):
             then = now
 
             if source_changed or past_midnight:
+                self.search.parse()
                 must_repaint = self.update_tasks()
 
             if must_repaint:
@@ -1718,7 +1750,10 @@ class CursesApplication(Application):
         assert isinstance(taskline, TaskLine)
         task = utils.ensure_up_to_date(taskline.task)
         if task is not None:
+            prev_version = str(task)
             fnc(task)
+            if str(task) == prev_version:
+                return False, task
             taskline.source.save(safe=self.safe_save)
             taskline.source.update_contexts_and_projects()
             self.search.update_sources(self.sources)
@@ -1950,6 +1985,30 @@ class CursesApplication(Application):
         if success:
             self.tasks.paint(True)
 
+    def do_prio_up(self):
+        if self.tasks.selected_item is None:
+            return
+        success, _ = self.modify_task(self.tasks.selected_item,
+                                      utils.increase_priority)
+        if success:
+            self.tasks.paint(True)
+
+    def do_prio_down(self):
+        if self.tasks.selected_item is None:
+            return
+        success, _ = self.modify_task(self.tasks.selected_item,
+                                      utils.decrease_priority)
+        if success:
+            self.tasks.paint(True)
+
+    def do_set_prio(self, prio):
+        if self.tasks.selected_item is None:
+            return
+        success, _ = self.modify_task(self.tasks.selected_item,
+                                      lambda t: utils.set_priority(t, prio))
+        if success:
+            self.tasks.paint(True)
+
     def do_show_help(self):
         self.focus.append(HelpScreen(self))
         height, width = self.size()
@@ -2100,23 +2159,28 @@ def run_cursesui(args):
 
     success = 0
     sources = utils.open_sources(args)
-    
+
     if len(sources) == 0:
         success = -1
-        print(tr("To start pter you must provide at least one todo.txt file. See --help for more information."),
+        print(tr("To start pter you must provide at least one todo.txt file. "
+                 "See --help for more information."),
               file=sys.stderr)
     else:
         search = Searcher('', False)
         search.update_sources(sources)
 
-        window = CursesApplication(sources, configuration.get_config(args))
+        window = CursesApplication(sources,
+                                   configuration.get_config(args),
+                                   args.search)
+
         exception = None
 
         try:
             window.run()
         except Exception as exc:
             callstack = ''.join(traceback.format_tb(exc.__traceback__))
-            logging.fatal(f"Pter crashed with exception: {exc}\n{callstack}")
+            logging.fatal("Pter crashed with exception: %s\n%s",
+                          exc, callstack)
             exception = exc
             success = -3
 
