@@ -670,7 +670,7 @@ class TaskDescriptionDelegate(QtWidgets.QAbstractItemDelegate):
         painter.setFont(task.context.font)
         painter.setClipRect(option.rect)
         middle = option.rect.y() + option.rect.height()/2
-        baseline = middle + task.context.baseline_offset
+        baseline = int(middle + task.context.baseline_offset)
         strike_height = baseline - task.context.strike_height
         cursor = option.rect.x()
         task.rects = []
@@ -1041,6 +1041,13 @@ class MainWindow(QMainWindow):
         self.actionDelegate = QtWidgets.QAction(tr("Dele&gate task"), self)
         self.actionNewRefTask = QtWidgets.QAction(tr("New &related task"), self)
         self.actionNewAfterTask = QtWidgets.QAction(tr("New &subsequent task"), self)
+        self.actionIncreasePrio = QtWidgets.QAction(tr("&Increase priority"), self)
+        self.actionDecreasePrio = QtWidgets.QAction(tr("De&crease priority"), self)
+        self.actionRemovePrio = QtWidgets.QAction(tr("Remove priority"), self)
+        self.actionSetPriorityA = QtWidgets.QAction(tr("A"), self)
+        self.actionSetPriorityB = QtWidgets.QAction(tr("B"), self)
+        self.actionSetPriorityC = QtWidgets.QAction(tr("C"), self)
+        self.actionSetPriorityD = QtWidgets.QAction(tr("D"), self)
         self.actionToggleDarkStyle = None
         self.actionDeleteTask = None
 
@@ -1120,6 +1127,15 @@ class MainWindow(QMainWindow):
         self.editMenu.addSeparator()
         self.editMenu.addAction(self.actionDelegate)
         self.editMenu.addSeparator()
+        priomenu = self.editMenu.addMenu(tr("Set priority"))
+        priomenu.addAction(self.actionSetPriorityA)
+        priomenu.addAction(self.actionSetPriorityB)
+        priomenu.addAction(self.actionSetPriorityC)
+        priomenu.addAction(self.actionSetPriorityD)
+        self.editMenu.addAction(self.actionIncreasePrio)
+        self.editMenu.addAction(self.actionDecreasePrio)
+        self.editMenu.addAction(self.actionRemovePrio)
+        self.editMenu.addSeparator()
         self.editMenu.addAction(self.actionToggleTracking)
         self.editMenu.addAction(self.actionToggleDone)
         self.editMenu.addAction(self.actionToggleHidden)
@@ -1151,12 +1167,21 @@ class MainWindow(QMainWindow):
                 (common.SETTING_GK_TOGGLE_HIDDEN, self.actionToggleHidden, Qt.WindowShortcut),
                 (common.SETTING_GK_DELEGATE, self.actionDelegate, Qt.WindowShortcut),
                 (common.SETTING_GK_TOGGLE_DARK, self.actionToggleDarkStyle, Qt.ApplicationShortcut),
+                (common.SETTING_GK_INC_PRIO, self.actionIncreasePrio, Qt.WindowShortcut),
+                (common.SETTING_GK_DEC_PRIO, self.actionDecreasePrio, Qt.WindowShortcut),
+                (common.SETTING_GK_REM_PRIO, self.actionRemovePrio, Qt.WindowShortcut),
+                (common.SETTING_GK_SET_PRIOA, self.actionSetPriorityA, Qt.WindowShortcut),
+                (common.SETTING_GK_SET_PRIOB, self.actionSetPriorityB, Qt.WindowShortcut),
+                (common.SETTING_GK_SET_PRIOC, self.actionSetPriorityC, Qt.WindowShortcut),
+                (common.SETTING_GK_SET_PRIOD, self.actionSetPriorityD, Qt.WindowShortcut),
                 ]
         if self.actionDeleteTask is not None:
-            keymapping.append((common.SETTING_GK_DELETE_TASK, self.actionDeleteTask, Qt.WindowShortcut))
+            keymapping.append((common.SETTING_GK_DELETE_TASK,
+                               self.actionDeleteTask,
+                               Qt.WindowShortcut))
 
         for name, target, context in keymapping:
-            keys = self.config.get(common.SETTING_GROUP_GUIKEYS, name)
+            keys = self.config.get(common.SETTING_GROUP_GUIKEYS, name, [])
             if len(keys) > 0 and target is not None:
                 target.setShortcut(QtGui.QKeySequence(keys))
                 target.setShortcutContext(context)
@@ -1445,6 +1470,13 @@ class Program:
         self.window.actionToggleTracking.triggered.connect(self.do_toggle_tracking)
         self.window.actionToggleHidden.triggered.connect(self.do_toggle_hidden)
         self.window.actionDelegate.triggered.connect(self.do_delegate)
+        self.window.actionIncreasePrio.triggered.connect(self.do_increase_prio)
+        self.window.actionDecreasePrio.triggered.connect(self.do_decrease_prio)
+        self.window.actionRemovePrio.triggered.connect(self.do_remove_prio)
+        self.window.actionSetPriorityA.triggered.connect(lambda: self.do_set_prio('A'))
+        self.window.actionSetPriorityB.triggered.connect(lambda: self.do_set_prio('B'))
+        self.window.actionSetPriorityC.triggered.connect(lambda: self.do_set_prio('C'))
+        self.window.actionSetPriorityD.triggered.connect(lambda: self.do_set_prio('D'))
         self.window.taskList.activated.connect(self.do_edit)
 
         if self.window.actionDeleteTask is not None:
@@ -1517,11 +1549,65 @@ class Program:
             ref = f"{reftype}:{refid}"
             self.window.creator.editor.setText(ref + " " + self.window.creator.editor.text())
 
+    def do_increase_prio(self):
+        taskindex = self.window.taskList.get_selected_index()
+        if taskindex is None:
+            return
+
+        taskindex = self.window.taskModel.ensure_up_to_date(taskindex)
+
+        if taskindex is not None:
+            task = taskindex.data(TASK_ROLE)
+            if utils.increase_priority(task):
+                task.todotxt.save(safe=self.safe_save)
+                self.window.taskModel.setData(taskindex, task)
+
+    def do_decrease_prio(self):
+        taskindex = self.window.taskList.get_selected_index()
+        if taskindex is None:
+            return
+
+        taskindex = self.window.taskModel.ensure_up_to_date(taskindex)
+
+        if taskindex is not None:
+            task = taskindex.data(TASK_ROLE)
+            if utils.decrease_priority(task):
+                task.todotxt.save(safe=self.safe_save)
+                self.window.taskModel.setData(taskindex, task)
+
+    def do_remove_prio(self):
+        taskindex = self.window.taskList.get_selected_index()
+        if taskindex is None:
+            return
+
+        taskindex = self.window.taskModel.ensure_up_to_date(taskindex)
+
+        if taskindex is not None:
+            task = taskindex.data(TASK_ROLE)
+            if task.priority is not None:
+                utils.set_priority(task, None)
+                task.todotxt.save(safe=self.safe_save)
+                self.window.taskModel.setData(taskindex, task)
+
+    def do_set_prio(self, prio):
+        taskindex = self.window.taskList.get_selected_index()
+        if taskindex is None:
+            return
+
+        taskindex = self.window.taskModel.ensure_up_to_date(taskindex)
+
+        if taskindex is not None:
+            task = taskindex.data(TASK_ROLE)
+            if task.priority != prio:
+                utils.set_priority(task, prio)
+                task.todotxt.save(safe=self.safe_save)
+                self.window.taskModel.setData(taskindex, task)
+
     def do_toggle_done(self):
         taskindex = self.window.taskList.get_selected_index()
         if taskindex is None:
             return
-        
+
         taskindex = self.window.taskModel.ensure_up_to_date(taskindex)
         if taskindex is not None:
             task = taskindex.data(TASK_ROLE)
