@@ -221,6 +221,37 @@ def toggle_hidden(task):
         task.add_attribute('h', '1')
 
 
+def set_priority(task, prio):
+    task.priority = prio
+    task.parse(str(task))
+
+
+def increase_priority(task):
+    """Increase the priority of `task`
+
+    Will do nothing if the task already has priority `(A)`.
+
+    Returns True if the priority has been increased, False otherwise."""
+    next_prio = {'B': 'A', 'C': 'B', 'D': 'C', None: 'D'}
+    if task.priority in next_prio:
+        set_priority(task, next_prio[task.priority])
+        return True
+    return False
+
+
+def decrease_priority(task):
+    """Decrease the priority of `task`
+
+    Will do nothing if the task has no priority.
+
+    Returns True if the priority has been decreased, False otherwise."""
+    next_prio = {'D': None, 'C': 'D', 'B': 'C', 'A': 'B'}
+    if task.priority in next_prio:
+        set_priority(task, next_prio[task.priority])
+        return True
+    return False
+
+
 def sign(n):
     if n < 0:
         return -1
